{% extends 'base.html' %}
{% load i18n %}

{% block title %}{% trans 'Logout' %}{% endblock %}

{% block body %}
	<p>{% trans 'Thanks for spending some quality time with the Web site today.' %}</p>
	<p><a href="{% url 'IS:index-home' %}">{% trans 'Log in again' %}</a></p>
{% endblock %}
