{% block tabs %}
	<ul class="nav nav-tabs">
		{% for tab in tabs %}
			<li{% if tab.active %} class="active"{% endif %}><a href="{{ tab.url }}">{{ tab.title|capfirst }}</a></li>
		{% endfor %}
	</ul>
{% endblock %}