{% extends 'forms/model_default_form.html' %}

{% block save-buttons %}
	{% if show_save_button %}
		{{ block.super }}
	{% endif %}
{% endblock %}

{% block required-hint %}
	{% if show_save_button %}
		{{ block.super }}
	{% endif %}
{% endblock %}
